
=================
 Example Listing
=================

2d_example.py
=============

.. literalinclude:: ../examples/2d_example.py

boundaryconditions_example.py
=============================

.. literalinclude:: ../examples/boundaryconditions_example.py


extension_velocities_example.py
===============================

.. literalinclude:: ../examples/extension_velocities_example.py
